import { useState, useEffect } from 'react';
import PetDisplay from './components/PetDisplay';
import InteractionMenu from './components/InteractionMenu';
import PetRegister from './components/PetRegister';
import { Pet } from './types/Pet';
import { fetchPets } from './services/api/api';

export default function App() {
  const [pet, setPet] = useState<Pet | null>(null);

  useEffect(() => {
    const loadPets = async () => {
      try {
        const pets = await fetchPets();
        if (pets.length > 0) {
          setPet(pets[0]);
        }
      } catch (error) {
        console.error('Error loading pets:', error);
      }
    };

    loadPets();
  }, []);

  const handleCustomize = () => {
    console.log('Customize pet');
  };

  const handlePetUpdate = (updatedPet: Pet) => {
    setPet(updatedPet);
  };

  if (!pet) {
    return <PetRegister onPetCreated={setPet} />;
  }

  return (
    <div className="min-h-screen bg-gray-900 text-white p-4">
      <div className="max-w-4xl mx-auto grid gap-8">
        <PetDisplay pet={pet} />
        <InteractionMenu
          pet={pet}
          onPetUpdate={handlePetUpdate}
          onCustomize={handleCustomize}
        />
      </div>
    </div>
  );
}